@@ -55,6 +55,8 @@ from shrike.pipeline.pipeline_config import default_config_dict, HDI_DEFAULT_CON
 from shrike.pipeline.telemetry_utils import TelemetryLogger
 from shrike._core import is_eyesoff_helper
 
+from functools import wraps
+
 
 log = logging.getLogger(__name__)
 
@@ -148,17 +150,41 @@ class AMLPipelineHelper:
 
     def component_load(self, component_key) -> Callable[..., "Component"]:
         """Loads one component from the manifest"""
-        return self.module_loader.load_module(component_key, self.required_modules())
+        component_func = self.module_loader.load_module(
+            component_key, self.required_modules()
+        )
+
+        @wraps(component_func)
+        def wrapper(*args, **kwargs):
+            component_step = component_func(*args, **kwargs)
+            log.info(
+                f"Now try applying the smart runsettting as component post load operation after component initialize: "
+            )
+            self.apply_smart_runsettings(component_step)
+            log.info(f"Successfully applied the smart runsettting. ")
+            return component_step
+
+        return wrapper
 
     def module_load(self, module_key):
         """Loads one module from the manifest"""
-        return self.module_loader.load_module(module_key, self.required_modules())
+        module_func = self.module_loader.load_module(
+            module_key, self.required_modules()
+        )
+
+        @wraps(module_func)
+        def wrapper(*args, **kwargs):
+            module_step = module_func(*args, **kwargs)
+            self.apply_smart_runsettings(module_step)
+            return module_step
+
+        return wrapper
 
     def subgraph_load(self, subgraph_key, custom_config=OmegaConf.create()) -> Callable:
         """Loads one subgraph from the manifest
         Args:
             subgraph_key (str): subgraph identifier that is used in the required_subgraphs() method
-            custom_config (DictConfig): custom configuration object, this custom object witll be
+            custom_config (DictConfig): custom configuration object, this custom object will be
             added to the pipeline config
 
         """
@@ -1008,27 +1034,6 @@ class AMLPipelineHelper:
                 f"During build() of graph class {self.__class__.__name__}, call to self.apply_recommended_runsettings() is wrong: key used as first argument ('{module_key}') maps to a module reference {module_manifest_entry} which name is different from the module instance provided as 2nd argument (name={module_instance.name}), did you use the wrong module key as first argument?"
             )
 
-    def _get_component_name_from_instance(self, component_instance):
-        component_manifest_list = self.config.modules.manifest
-        component_name = component_instance.name
-        for component_manifest_entry in component_manifest_list:
-            try:
-                if component_manifest_entry["name"] == component_name:
-                    return component_manifest_entry["key"] or component_name
-                if "namespace" in component_manifest_entry:
-                    component_entry_name = (
-                        component_manifest_entry["namespace"]
-                        + "://"
-                        + component_manifest_entry["name"]
-                    )
-                    if component_entry_name == component_name:
-                        return component_manifest_entry["key"] or component_name
-            except:
-                pass
-        raise ValueError(
-            f"Could not find component matching {component_name}. Please check your spelling."
-        )
-
     def apply_smart_runsettings(
         self,
         component_instance,
@@ -1056,10 +1061,8 @@ class AMLPipelineHelper:
             sweep (bool): is the component using sweep?
             custom_runtime_arguments (dict): any additional custom args
         """
-        # infer component_name
-        component_name = self._get_component_name_from_instance(component_instance)
         self.apply_recommended_runsettings(
-            component_name,
+            component_instance.name,
             component_instance,
             gpu,
             hdi,
